@@ -26,6 +26,7 @@ var NAVTREE =
 [
   [ "StarPU Handbook", "index.html", [
     [ "Introduction", "index.html", [
+      [ "we need to keep 2 blank lines above", "index.html#autotoc_md0", null ],
       [ "Motivation", "index.html#Motivation", null ],
       [ "StarPU in a Nutshell", "index.html#StarPUInANutshell", [
         [ "Codelet and Tasks", "index.html#CodeletAndTasks", null ],
@@ -40,7 +41,8 @@ var NAVTREE =
     [ "Building and Installing StarPU", "BuildingAndInstallingStarPU.html", [
       [ "Installing a Binary Package", "BuildingAndInstallingStarPU.html#InstallingABinaryPackage", null ],
       [ "Installing a Source Package", "BuildingAndInstallingStarPU.html#InstallingASourcePackage", [
-        [ "Installing the Spack Package", "BuildingAndInstallingStarPU.html#SpackInstallation", null ]
+        [ "Installing the Spack Package", "BuildingAndInstallingStarPU.html#SpackInstallation", null ],
+        [ "Using a Module", "BuildingAndInstallingStarPU.html#UsingModule", null ]
       ] ],
       [ "Building from Source", "BuildingAndInstallingStarPU.html#InstallingFromSource", [
         [ "Optional Dependencies", "BuildingAndInstallingStarPU.html#OptionalDependencies", null ],
@@ -162,10 +164,19 @@ var NAVTREE =
     ] ],
     [ "Examples in StarPU Sources", "ExamplesInStarPUSources.html", null ],
     [ "------— StarPU Applications ------—", "IntroApplications.html", null ],
+    [ "A Vector Scaling Application", "VectorApplication.html", [
+      [ "Base version", "VectorApplication.html#BaseVersion", null ],
+      [ "StarPU C version", "VectorApplication.html#StarPUCversion", [
+        [ "Computation Kernels", "VectorApplication.html#ComputationKernels", null ],
+        [ "Main Code", "VectorApplication.html#MainCode", null ]
+      ] ],
+      [ "Building and Running", "VectorApplication.html#BuildingandRunning", null ]
+    ] ],
     [ "A Stencil Application", "StencilApplication.html", [
       [ "The Original Application", "StencilApplication.html#StencilOriginal", null ],
       [ "The StarPU Application", "StencilApplication.html#StencilStarPU", null ],
-      [ "The StarPU MPI Application", "StencilApplication.html#StencilStarPUMPI", null ]
+      [ "The StarPU MPI Application", "StencilApplication.html#StencilStarPUMPI", null ],
+      [ "Running the application", "StencilApplication.html#StencilRunning", null ]
     ] ],
     [ "------— StarPU Performances ------—", "IntroPerformances.html", null ],
     [ "Benchmarking StarPU", "BenchmarkingStarPU.html", [
@@ -348,7 +359,8 @@ var NAVTREE =
         [ "Performances", "PythonInterface.html#JobLibPerformances", null ]
       ] ],
       [ "Multiple Interpreters", "PythonInterface.html#MultipleInterpreters", null ],
-      [ "Master Slave Support", "PythonInterface.html#StarpupyMasterSlave", null ]
+      [ "Master Slave Support", "PythonInterface.html#StarpupyMasterSlave", null ],
+      [ "StarPUPY and Simgrid", "PythonInterface.html#StarPUPYSimgrid", null ]
     ] ],
     [ "The StarPU OpenMP Runtime Support (SORS)", "OpenMPRuntimeSupport.html", [
       [ "Implementation Details and Specificities", "OpenMPRuntimeSupport.html#OMPImplementation", [
@@ -615,21 +627,21 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "AdvancedDataManagement.html",
-"NativeFortranSupport.html#NFImplementation",
-"functions_vars.html",
-"group__API__Codelet__And__Tasks.html#ga95fcc50dde65c79b011c1269fc926dd8",
-"group__API__Data__Interfaces.html#ga487b41c917f6317221d85ab626afd353",
-"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbaab55b4cef9cfedeacae7012cd52e5389",
-"group__API__Initialization__and__Termination.html#ga8372a8e258ff7e39b313e8c0992905b3",
-"group__API__MPI__Support.html#gacb05635d95f946f099a1772c8bd59c8b",
-"group__API__OpenMP__Runtime__Support.html#ga478c43dbbdd549ebe481610fd42e1b92",
-"group__API__Perf__Steering.html#ggaa8f9f7eab09618e42e51577cd0b51486aa15e67713b78b1310fc9bdd20eb6120c",
-"group__API__SC__Hypervisor.html#gae897baba953584f77fda8c65ae7b25d1",
-"group__API__Theoretical__Lower__Bound__on__Execution__Time.html#ga284f3571becb60b2354cc1ce121e4778",
-"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html",
-"interfacefstarpu__mod_1_1fstarpu__insert__task.html",
-"interfacefstarpu__mod_1_1fstarpu__tensor__get__ptr.html",
-"starpu__driver_8h_source.html"
+"NativeFortranSupport.html#NFIdioms",
+"functions_m.html",
+"group__API__Codelet__And__Tasks.html#ga842f80f41741306e78963d5b1cec4b7f",
+"group__API__Data__Interfaces.html#ga3ef8a3c5b91f3d3b048a4e5f51a4c4c0",
+"group__API__Data__Management.html#gaf971c53b3fa3d3746a8ae1f5291c7c4f",
+"group__API__Initialization__and__Termination.html#ga06215a557f489ef2dd936f691e395eb7",
+"group__API__MPI__Support.html#gab1cdef357b93d4f9f332199da819b792",
+"group__API__OpenMP__Runtime__Support.html#ga2c980c583e9faf124b4446fa90b5ece9",
+"group__API__Perf__Steering.html#gaa3355e070b7f2275deb8616bc3a8bb9b",
+"group__API__SC__Hypervisor.html#gab4e7dd4e4841b9e3db584b903043c3ad",
+"group__API__Task__Lists.html#ga56ae6bd10619777a164ace85197034c4",
+"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html",
+"interfacefstarpu__mod_1_1fstarpu__free__noflag.html",
+"interfacefstarpu__mod_1_1fstarpu__task__wait__for__no__ready.html",
+"starpu__cusolver_8h.html#a802c617673805d37d62a3213261d121e"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
