@@ -1,5 +1,8 @@
 var NAVTREEINDEX4 =
 {
+"group__API__FFT__Support.html#gabff378384df24d2c2ea296397b600569":[10,1,4],
+"group__API__FFT__Support.html#gae73ea67d1d7df63938661c7a1105800a":[10,1,5],
+"group__API__FFT__Support.html#gaf263d43c43927007819edf069cc8c93b":[10,1,2],
 "group__API__Fortran.html":[10,2],
 "group__API__FxT__Support.html":[10,34],
 "group__API__FxT__Support.html#a0354339f996ded0f2c8e4863c38a8cda":[10,34,1,1],
@@ -246,8 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__Interop__Support.html#gabac59e33ab90205796c3c32088c9dca7":[10,50,27],
 "group__API__Interop__Support.html#gabfa1459181ebb9b71f185d42d2414d91":[10,50,44],
 "group__API__Interop__Support.html#gad05a3754e71e0dfb86d2ae5633287e7a":[10,50,52],
-"group__API__Interop__Support.html#gad16a15386b4f7b1f8156a6b6db93db3f":[10,50,20],
-"group__API__Interop__Support.html#gad2311ec339344d00bf5afdfa0ae4077b":[10,50,22],
-"group__API__Interop__Support.html#gad2af4e59ecca5dd01e2a7b914862c73c":[10,50,35],
-"group__API__Interop__Support.html#gadc9f8a043f8d1c2b44f0f942b0a8017c":[10,50,28]
+"group__API__Interop__Support.html#gad16a15386b4f7b1f8156a6b6db93db3f":[10,50,20]
 };
