@@ -1,5 +1,8 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Modularized__Scheduler.html#gaa838921844068ca3190dca5e2b5a99db":[10,22,13],
+"group__API__Modularized__Scheduler.html#gaab8471a2921b0508b9269b08ecfba3b7":[10,22,42],
+"group__API__Modularized__Scheduler.html#gab17420484cfb68122d986d1feee91905":[10,22,76],
 "group__API__Modularized__Scheduler.html#gab40975877d0c861348ccc96602be2cae":[10,22,25],
 "group__API__Modularized__Scheduler.html#gab8540c0e69c3af17c424944af9b3c802":[10,22,27],
 "group__API__Modularized__Scheduler.html#gabd7a0274979659050496fcc1c66b7a1c":[10,22,8],
@@ -246,8 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Parallel__Worker.html#ga5dc009221d5edb074372761574238dac":[10,37,6],
 "group__API__Parallel__Worker.html#ga63c001ace567446514f1616e34af1bf6":[10,37,29],
 "group__API__Parallel__Worker.html#ga6418a1fed34b32217d66860cbf8fc200":[10,37,24],
-"group__API__Parallel__Worker.html#ga6cd34b24aaea1b26df96b7aff9238759":[10,37,22],
-"group__API__Parallel__Worker.html#ga6dc4b6d66ef90b7927559c9e2728a84b":[10,37,21],
-"group__API__Parallel__Worker.html#ga6e2258c377e3aa838c2120904bf96f99":[10,37,34],
-"group__API__Parallel__Worker.html#ga718ac3b3060472256eceb68147a112b9":[10,37,26]
+"group__API__Parallel__Worker.html#ga6cd34b24aaea1b26df96b7aff9238759":[10,37,22]
 };
