@@ -1,5 +1,8 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Parallel__Worker.html#ga6dc4b6d66ef90b7927559c9e2728a84b":[10,37,21],
+"group__API__Parallel__Worker.html#ga6e2258c377e3aa838c2120904bf96f99":[10,37,34],
+"group__API__Parallel__Worker.html#ga718ac3b3060472256eceb68147a112b9":[10,37,26],
 "group__API__Parallel__Worker.html#ga777b13d6f49389771ce70e5c0fdfaf70":[10,37,33],
 "group__API__Parallel__Worker.html#ga7ebcf92c32971a58683063b536698996":[10,37,5],
 "group__API__Parallel__Worker.html#ga88471707cf8021453892ca7d83124bea":[10,37,13],
@@ -246,8 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling.html#aed6a8be9b919f03e093912bfc44c5559":[10,40,1,0],
 "group__API__Profiling.html#ga1e388939370daaf139c73678e413f00a":[10,40,3],
 "group__API__Profiling.html#ga4e4f9fb593d29219a1109062ba9d72ef":[10,40,22],
-"group__API__Profiling.html#ga6511f50290edcabbdf605a1b74746645":[10,40,21],
-"group__API__Profiling.html#ga6ab0a1e4a8a55e0c54e2151fd0a82a36":[10,40,5],
-"group__API__Profiling.html#ga76ad19fc8b99bcd42d505c76aafae6b6":[10,40,18],
-"group__API__Profiling.html#ga7c70803a54aa1e5b463ebb19110c4aa2":[10,40,11]
+"group__API__Profiling.html#ga6511f50290edcabbdf605a1b74746645":[10,40,21]
 };
