@@ -1,5 +1,8 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Profiling.html#ga6ab0a1e4a8a55e0c54e2151fd0a82a36":[10,40,5],
+"group__API__Profiling.html#ga76ad19fc8b99bcd42d505c76aafae6b6":[10,40,18],
+"group__API__Profiling.html#ga7c70803a54aa1e5b463ebb19110c4aa2":[10,40,11],
 "group__API__Profiling.html#ga858f465a2dcbcadb6169a7926e38a4d1":[10,40,12],
 "group__API__Profiling.html#ga87639260ff5c89f466e83fcc093e77fe":[10,40,20],
 "group__API__Profiling.html#ga8a423df93ec48a7391b2f439357a5544":[10,40,9],
@@ -246,8 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Scheduling__Policy.html#a9020a364719389cd19c31a657c938293":[10,24,0,10],
 "group__API__Scheduling__Policy.html#ace93b3c465e39c7e2ca894406905dc2a":[10,24,0,0],
 "group__API__Scheduling__Policy.html#ad720f2cd2155e8baa10f57792b68a5eb":[10,24,0,8],
-"group__API__Scheduling__Policy.html#afd00e4e0a058e043c3d8edf916ace4f7":[10,24,0,7],
-"group__API__Scheduling__Policy.html#ga1e159d56ffa2d7705bdfd1ceb93e0d64":[10,24,36],
-"group__API__Scheduling__Policy.html#ga20525c5d674b32a9f64fbc9e23c5f55f":[10,24,23],
-"group__API__Scheduling__Policy.html#ga21385d19bc75a7581e774bd455c70790":[10,24,28]
+"group__API__Scheduling__Policy.html#afd00e4e0a058e043c3d8edf916ace4f7":[10,24,0,7]
 };
