@@ -1,5 +1,8 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Policy.html#ga1e159d56ffa2d7705bdfd1ceb93e0d64":[10,24,36],
+"group__API__Scheduling__Policy.html#ga20525c5d674b32a9f64fbc9e23c5f55f":[10,24,23],
+"group__API__Scheduling__Policy.html#ga21385d19bc75a7581e774bd455c70790":[10,24,28],
 "group__API__Scheduling__Policy.html#ga24154b37920144de18bca59090429d6d":[10,24,18],
 "group__API__Scheduling__Policy.html#ga2bb5cf545414379c1425a4b399fd75c2":[10,24,6],
 "group__API__Scheduling__Policy.html#ga2c45db0c01e86497082c907b9cb0f4cc":[10,24,14],
@@ -246,8 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#ga35c8908fd60c0407901872b25a8a88da":[10,18,68],
 "group__API__Workers.html#ga389142e108345483dc8c0bf07465263c":[10,18,49],
 "group__API__Workers.html#ga38c0b1858730fec2211991147a964910":[10,18,69],
-"group__API__Workers.html#ga39b7e2b82022313535c7b0015c2a0176":[10,18,45],
-"group__API__Workers.html#ga3a6a9eddecb3e97b3c37e151003ea7c2":[10,18,32],
-"group__API__Workers.html#ga3c4c7e122c29d884fe1674434b69cf52":[10,18,22],
-"group__API__Workers.html#ga3f985e55d355aa7b1c83471230b37a39":[10,18,39]
+"group__API__Workers.html#ga39b7e2b82022313535c7b0015c2a0176":[10,18,45]
 };
