@@ -265,17 +265,17 @@ var NAVTREEINDEX =
 "group__API__Bitmap.html#ga13e39b685a536b85ed319cfcb97743a4",
 "group__API__Codelet__And__Tasks.html#gga0088c4ab87a08b3e7a375c1a79e91202a5ee20d5e9ae6d031161f7d601f5c44ee",
 "group__API__Data__Interfaces.html#ga7e3ef9efbc7a65adad27f9ac27493493",
-"group__API__Data__Partition.html#ga4b910784c11bb46599fe9cb8928418f2",
-"group__API__Insert__Task.html#ga5776bda054d4e57b7477e292bcc10a0e",
-"group__API__Miscellaneous__Helpers.html#ga205dc8faae407fe2c524968badf99fef",
-"group__API__OpenMP__Runtime__Support.html#gab77e220adc13d13b4d0db0e1df83a2a9",
-"group__API__Performance__Model.html#ab73609496a2f81bca58a7c864b434441",
-"group__API__SC__Hypervisor__usage.html#ga7b4cd59e4c0011400e7be4d4799e6b85",
-"group__API__Threads.html#ga81126f750a75beef8a9679dd261e1bd2",
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html",
-"interfacefstarpu__mod_1_1fstarpu__perfmodel__free.html",
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html",
-"starpu__sched__ctx__hypervisor_8h.html#a95283c927a7787e2859cb4a42c93bf19"
+"group__API__Data__Partition.html#ga46d2b144a7de2e17d17b1383ef5f522d",
+"group__API__Insert__Task.html#ga502e5ec7928054775798a57a930bb12b",
+"group__API__Miscellaneous__Helpers.html#ga090e97b588f83718c19f0ed3d07d1d70",
+"group__API__OpenMP__Runtime__Support.html#gaac482422d2b9bc26c1877f49eaa5fca2",
+"group__API__Performance__Model.html#aa82fae955253d333733d34fe4a44e298",
+"group__API__SC__Hypervisor__usage.html#ga6398be50d801f0fc5ad73506e392d476",
+"group__API__Threads.html#ga670ae411d7536934d784c88c6d11177c",
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html",
+"interfacefstarpu__mod_1_1fstarpu__parallel__task__barrier__init__n__init__n.html",
+"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html",
+"starpu__rand_8h_source.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
