@@ -1,5 +1,8 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Threads.html#ga670ae411d7536934d784c88c6d11177c":[25,3,28],
+"group__API__Threads.html#ga707b1afc766917d4ddbbe19e5569359b":[25,3,23],
+"group__API__Threads.html#ga7cf8cbee2a33b4714cf37724f657bd4a":[25,3,15],
 "group__API__Threads.html#ga81126f750a75beef8a9679dd261e1bd2":[25,3,21],
 "group__API__Threads.html#ga85907c2f14430e01fea27280ed3ac2ae":[25,3,41],
 "group__API__Threads.html#ga8cda60ccc235761b6fea9ec2204da362":[25,3,3],
@@ -245,9 +248,6 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[26,0,0,32],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[27,0,0,33],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[26,0,0,33],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[27,0,0,34],
 "interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[26,0,0,34],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[27,0,0,35],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__nbuffers.html":[26,0,0,35],
-"interfacefstarpu__mod_1_1fstarpu__codelet__set__type.html":[27,0,0,36]
+"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[27,0,0,34]
 };
