@@ -1,30 +1,37 @@
 var NAVTREEINDEX13 =
 {
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[27,0,0,286],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[27,0,0,287],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[26,0,0,287],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[27,0,0,288],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[26,0,0,288],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[27,0,0,289],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[26,0,0,289],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[27,0,0,290],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[26,0,0,290],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[27,0,0,291],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[26,0,0,291],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[26,0,0,292],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[27,0,0,292],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[26,0,0,293],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[27,0,0,293],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[27,0,0,294],
-"interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[26,0,0,294],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[27,0,0,295],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[26,0,0,295],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[27,0,0,296],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[26,0,0,296],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[27,0,0,297],
-"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[26,0,0,297],
-"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[27,0,0,298],
-"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[26,0,0,298],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[27,0,0,285],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__bindid.html":[26,0,0,285],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[27,0,0,286],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__by__devid.html":[26,0,0,286],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[27,0,0,287],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__by__type.html":[26,0,0,287],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[27,0,0,288],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count.html":[26,0,0,288],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[26,0,0,289],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__count__by__type.html":[27,0,0,289],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[27,0,0,290],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__devid.html":[26,0,0,290],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[26,0,0,291],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__id.html":[27,0,0,291],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[26,0,0,292],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__ids__by__type.html":[27,0,0,292],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[26,0,0,293],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__memory__node.html":[27,0,0,293],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[26,0,0,294],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__name.html":[27,0,0,294],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[26,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__type.html":[27,0,0,295],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[27,0,0,296],
+"interfacefstarpu__mod_1_1fstarpu__worker__get__type__as__string.html":[26,0,0,296],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[27,0,0,297],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__blocked.html":[26,0,0,297],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[27,0,0,298],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__combined__worker.html":[26,0,0,298],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[27,0,0,299],
+"interfacefstarpu__mod_1_1fstarpu__worker__is__slave__somewhere.html":[26,0,0,299],
+"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[27,0,0,300],
+"interfacefstarpu__mod_1_1fstarpug__data__ptr__register.html":[26,0,0,300],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__barrier.html":[27,0,1,0],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush.html":[27,0,1,1],
 "interfacefstarpu__mpi__mod_1_1fstarpu__mpi__cache__flush__all__data.html":[27,0,1,2],
@@ -242,12 +249,5 @@ var NAVTREEINDEX13 =
 "starpu__profiling_8h_source.html":[28,0,1,29],
 "starpu__profiling__tool_8h.html":[28,0,1,30],
 "starpu__profiling__tool_8h_source.html":[28,0,1,30],
-"starpu__rand_8h.html":[28,0,1,31],
-"starpu__rand_8h_source.html":[28,0,1,31],
-"starpu__sched__component_8h.html":[28,0,1,32],
-"starpu__sched__component_8h_source.html":[28,0,1,32],
-"starpu__sched__ctx_8h.html":[28,0,1,33],
-"starpu__sched__ctx_8h_source.html":[28,0,1,33],
-"starpu__sched__ctx__hypervisor_8h.html":[28,0,1,34],
-"starpu__sched__ctx__hypervisor_8h.html#a62867177a48ccd40ac944602630cd8f0":[28,0,1,34,2]
+"starpu__rand_8h.html":[28,0,1,31]
 };
