@@ -1,5 +1,8 @@
 var NAVTREEINDEX5 =
 {
+"group__API__Insert__Task.html#ga502e5ec7928054775798a57a930bb12b":[25,13,55],
+"group__API__Insert__Task.html#ga51d0a8fa43d9289b8c9da5450faf76ad":[25,13,52],
+"group__API__Insert__Task.html#ga57022b36ea715a26133a90144265f6e1":[25,13,27],
 "group__API__Insert__Task.html#ga5776bda054d4e57b7477e292bcc10a0e":[25,13,33],
 "group__API__Insert__Task.html#ga582525adc5ca103f84250a2cac901dd9":[25,13,30],
 "group__API__Insert__Task.html#ga5d7d1a3f2cf7d884f16f2838679de8fe":[25,13,19],
@@ -246,8 +249,5 @@ var NAVTREEINDEX5 =
 "group__API__Max__FPGA__Extensions.html#ga7f7a92414ff1a98d7523bc40f36d0878":[25,17,2],
 "group__API__Max__FPGA__Extensions.html#gaab45e70c85fc1786d6d5e618fd5c3922":[25,17,3],
 "group__API__Max__FPGA__Extensions.html#structstarpu__max__load":[25,17,0],
-"group__API__Miscellaneous__Helpers.html":[25,36],
-"group__API__Miscellaneous__Helpers.html#ga090e97b588f83718c19f0ed3d07d1d70":[25,36,14],
-"group__API__Miscellaneous__Helpers.html#ga0e762c057c5206bd093534e5dd145b1c":[25,36,17],
-"group__API__Miscellaneous__Helpers.html#ga127022a5dde360045b603e47a5faf303":[25,36,20]
+"group__API__Miscellaneous__Helpers.html":[25,36]
 };
