@@ -1,5 +1,8 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Miscellaneous__Helpers.html#ga090e97b588f83718c19f0ed3d07d1d70":[25,36,14],
+"group__API__Miscellaneous__Helpers.html#ga0e762c057c5206bd093534e5dd145b1c":[25,36,17],
+"group__API__Miscellaneous__Helpers.html#ga127022a5dde360045b603e47a5faf303":[25,36,20],
 "group__API__Miscellaneous__Helpers.html#ga205dc8faae407fe2c524968badf99fef":[25,36,10],
 "group__API__Miscellaneous__Helpers.html#ga30a209003955a8e4d528a3efa224a7d8":[25,36,19],
 "group__API__Miscellaneous__Helpers.html#ga34953348991f74a1cbd694fffb27f8b7":[25,36,15],
@@ -246,8 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__OpenMP__Runtime__Support.html#gaa4b70af0a6cf757e05e300c5eeea0a46":[25,21,8],
 "group__API__OpenMP__Runtime__Support.html#gaa5c38dfec313088ca5e527a97f40969d":[25,21,7],
 "group__API__OpenMP__Runtime__Support.html#gaa63576df9729394a3d53137d7021bab5":[25,21,35],
-"group__API__OpenMP__Runtime__Support.html#gaa862fb6fec908c7707daa274ae5950bd":[25,21,90],
-"group__API__OpenMP__Runtime__Support.html#gaac482422d2b9bc26c1877f49eaa5fca2":[25,21,57],
-"group__API__OpenMP__Runtime__Support.html#gaaf0d71971d1ab1b0d4f9919830693d98":[25,21,14],
-"group__API__OpenMP__Runtime__Support.html#gab2727bdd191a5d1c495dc01ccf9872f0":[25,21,82]
+"group__API__OpenMP__Runtime__Support.html#gaa862fb6fec908c7707daa274ae5950bd":[25,21,90]
 };
