@@ -1,5 +1,8 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Performance__Model.html#aa82fae955253d333733d34fe4a44e298":[25,20,5,1],
+"group__API__Performance__Model.html#ab1a7822099d984503f1c67d45ab6f4b8":[25,20,2,2],
+"group__API__Performance__Model.html#ab718a53c300f99766bdc42ca1909b49b":[25,20,4,9],
 "group__API__Performance__Model.html#ab73609496a2f81bca58a7c864b434441":[25,20,0,0],
 "group__API__Performance__Model.html#ab98cb01511c0fc3dfccdee0265137440":[25,20,6,7],
 "group__API__Performance__Model.html#ac4ea9dce00af99aa0f3eb21e4d4300f6":[25,20,6,3],
@@ -246,8 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__SC__Hypervisor__usage.html#ga4c83e2984867267ea8c7da9fbaf23858":[25,49,2],
 "group__API__SC__Hypervisor__usage.html#ga4dfbeda855bb8963c5332fdd796c0dcf":[25,49,18],
 "group__API__SC__Hypervisor__usage.html#ga5f2b33a41a697759ee2a222e623f723c":[25,49,4],
-"group__API__SC__Hypervisor__usage.html#ga5f34faa17f98f25bd874950ba1a15578":[25,49,15],
-"group__API__SC__Hypervisor__usage.html#ga6398be50d801f0fc5ad73506e392d476":[25,49,17],
-"group__API__SC__Hypervisor__usage.html#ga67d1dbb2ab01c8b712a9cd270fba4155":[25,49,5],
-"group__API__SC__Hypervisor__usage.html#ga6fd674769c96a6b13b4e1b0d2e5a4f68":[25,49,20]
+"group__API__SC__Hypervisor__usage.html#ga5f34faa17f98f25bd874950ba1a15578":[25,49,15]
 };
