@@ -1,5 +1,8 @@
 var NAVTREEINDEX9 =
 {
+"group__API__SC__Hypervisor__usage.html#ga6398be50d801f0fc5ad73506e392d476":[25,49,17],
+"group__API__SC__Hypervisor__usage.html#ga67d1dbb2ab01c8b712a9cd270fba4155":[25,49,5],
+"group__API__SC__Hypervisor__usage.html#ga6fd674769c96a6b13b4e1b0d2e5a4f68":[25,49,20],
 "group__API__SC__Hypervisor__usage.html#ga7b4cd59e4c0011400e7be4d4799e6b85":[25,49,24],
 "group__API__SC__Hypervisor__usage.html#ga886533650f0dbbef618c7fdfa75f9f0e":[25,49,9],
 "group__API__SC__Hypervisor__usage.html#ga960ae31e317c65bfa9cc6a4e539a0c84":[25,49,14],
@@ -246,8 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Threads.html#ga5e53025adc42966a97d616304bd654bd":[25,3,6],
 "group__API__Threads.html#ga5ec606cedc543ee35f3c7dc8a8e2505b":[25,3,64],
 "group__API__Threads.html#ga629152a86070cd58811fa17506f7995e":[25,3,12],
-"group__API__Threads.html#ga654b486b4161002221a75cc619eabe48":[25,3,30],
-"group__API__Threads.html#ga670ae411d7536934d784c88c6d11177c":[25,3,28],
-"group__API__Threads.html#ga707b1afc766917d4ddbbe19e5569359b":[25,3,23],
-"group__API__Threads.html#ga7cf8cbee2a33b4714cf37724f657bd4a":[25,3,15]
+"group__API__Threads.html#ga654b486b4161002221a75cc619eabe48":[25,3,30]
 };
