@@ -1,5 +1,8 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Workers.html#gac043c52077692456604a2f2f161b86ba":[5,18,57],
+"group__API__Workers.html#gac5ac7db6daab005d9c36c2481d984b66":[5,18,40],
+"group__API__Workers.html#gac6d06f4e22b63bf50bc8e836cf16f81f":[5,18,21],
 "group__API__Workers.html#gacb9d262c066c047ae55f691adc876db3":[5,18,16],
 "group__API__Workers.html#gacdc94f67f203028dbfc25a2e8b588bb5":[5,18,62],
 "group__API__Workers.html#gace5e9c1624f4d6449b22857b38326e9e":[5,18,73],
@@ -155,99 +158,96 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[6,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[7,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[6,0,0,57],
-"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[7,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[6,0,0,58],
-"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[6,0,0,59],
+"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[7,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[7,0,0,59],
-"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[6,0,0,60],
+"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[6,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[7,0,0,60],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[6,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[7,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[6,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[7,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[6,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[7,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[6,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[7,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[6,0,0,65],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[7,0,0,65],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[6,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[7,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[7,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[6,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[7,0,0,68],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[6,0,0,68],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[7,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[6,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[7,0,0,70],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[6,0,0,70],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[7,0,0,71],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[6,0,0,71],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[6,0,0,72],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[7,0,0,72],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[6,0,0,73],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[7,0,0,73],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[6,0,0,74],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[7,0,0,74],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[6,0,0,75],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[7,0,0,75],
-"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[7,0,0,76],
-"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[6,0,0,76],
-"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[7,0,0,77],
-"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[6,0,0,77],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[7,0,0,78],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[6,0,0,78],
-"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[6,0,0,79],
-"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[7,0,0,79],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[7,0,0,80],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[6,0,0,80],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[7,0,0,81],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[6,0,0,81],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[6,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[7,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[6,0,0,83],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[7,0,0,83],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[6,0,0,84],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[7,0,0,84],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[7,0,0,85],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[6,0,0,85],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[7,0,0,86],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[6,0,0,86],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[7,0,0,87],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[6,0,0,87],
-"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[7,0,0,88],
-"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[6,0,0,88],
-"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[6,0,0,89],
-"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[7,0,0,89],
-"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[7,0,0,90],
-"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[6,0,0,90],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[6,0,0,91],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[7,0,0,91],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[7,0,0,92],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[6,0,0,92],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[7,0,0,93],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[6,0,0,93],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[7,0,0,94],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[6,0,0,94],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[7,0,0,95],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[6,0,0,95],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[7,0,0,96],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[6,0,0,96],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[7,0,0,97],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[6,0,0,97],
-"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[7,0,0,98],
-"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[6,0,0,98],
-"interfacefstarpu__mod_1_1fstarpu__data__release.html":[7,0,0,99],
-"interfacefstarpu__mod_1_1fstarpu__data__release.html":[6,0,0,99],
-"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[6,0,0,100],
-"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[7,0,0,100],
-"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[6,0,0,101],
-"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[7,0,0,101],
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[6,0,0,102],
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[7,0,0,102],
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[6,0,0,103],
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[7,0,0,103],
-"interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[6,0,0,104],
-"interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[7,0,0,104],
-"interfacefstarpu__mod_1_1fstarpu__data__unpartition.html":[6,0,0,105]
+"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[6,0,0,60],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[6,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[7,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[6,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[7,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[6,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[7,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[6,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[7,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[6,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[7,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[6,0,0,66],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[7,0,0,66],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[7,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[6,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[6,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[7,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[7,0,0,69],
+"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[6,0,0,69],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[7,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[6,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[6,0,0,71],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[7,0,0,71],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[6,0,0,72],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[7,0,0,72],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[6,0,0,73],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[7,0,0,73],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[6,0,0,74],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[7,0,0,74],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[6,0,0,75],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[7,0,0,75],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[7,0,0,76],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[6,0,0,76],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[7,0,0,77],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[6,0,0,77],
+"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[7,0,0,78],
+"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[6,0,0,78],
+"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[6,0,0,79],
+"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[7,0,0,79],
+"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[7,0,0,80],
+"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[6,0,0,80],
+"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[7,0,0,81],
+"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[6,0,0,81],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[7,0,0,82],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[6,0,0,82],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[7,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[6,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[7,0,0,84],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[6,0,0,84],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[7,0,0,85],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[6,0,0,85],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[7,0,0,86],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[6,0,0,86],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[7,0,0,87],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[6,0,0,87],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[7,0,0,88],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[6,0,0,88],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[6,0,0,89],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[7,0,0,89],
+"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[6,0,0,90],
+"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[7,0,0,90],
+"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[6,0,0,91],
+"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[7,0,0,91],
+"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[6,0,0,92],
+"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[7,0,0,92],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[7,0,0,93],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[6,0,0,93],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[7,0,0,94],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[6,0,0,94],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[7,0,0,95],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[6,0,0,95],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[7,0,0,96],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[6,0,0,96],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[7,0,0,97],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[6,0,0,97],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[7,0,0,98],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[6,0,0,98],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[7,0,0,99],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[6,0,0,99],
+"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[6,0,0,100],
+"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[7,0,0,100],
+"interfacefstarpu__mod_1_1fstarpu__data__release.html":[6,0,0,101],
+"interfacefstarpu__mod_1_1fstarpu__data__release.html":[7,0,0,101],
+"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[6,0,0,102],
+"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[7,0,0,102],
+"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[6,0,0,103],
+"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[7,0,0,103]
 };
