@@ -1,5 +1,8 @@
 var NAVTREEINDEX4 =
 {
+"group__API__HIP__Extensions.html#gadc796fee8ebed3e8f4c12fb242f4c857":[5,16,4],
+"group__API__HIP__Extensions.html#gaea7ebef965850bb064607be8103e2c92":[5,16,9],
+"group__API__HeteroPrio.html":[5,25],
 "group__API__HeteroPrio.html#ga08616241ba1e2b52a418b7de4c03895a":[5,25,7],
 "group__API__HeteroPrio.html#ga1756abbc3f96c7e3330313d00f40ba05":[5,25,4],
 "group__API__HeteroPrio.html#ga287b5ba0e2b8d972ba5cf8785ede1f62":[5,25,5],
@@ -246,8 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__MPI__Support.html#ga1def2741166f560a0fb91f012538087f":[5,27,117],
 "group__API__MPI__Support.html#ga223329eeb7c711b1b213604355981185":[5,27,7],
 "group__API__MPI__Support.html#ga234e28905c976ed1b03fcdf75812a06d":[5,27,23],
-"group__API__MPI__Support.html#ga23d04f0a7ca146314a02e4773dafde2e":[5,27,60],
-"group__API__MPI__Support.html#ga25408759187b030c633314855589ebcd":[5,27,91],
-"group__API__MPI__Support.html#ga2816a57287cd1a4babd27105936fc6ed":[5,27,109],
-"group__API__MPI__Support.html#ga2bfc2db9d324c76cae7a107ce3cd2cf8":[5,27,64]
+"group__API__MPI__Support.html#ga23d04f0a7ca146314a02e4773dafde2e":[5,27,60]
 };
