@@ -1,5 +1,8 @@
 var NAVTREEINDEX5 =
 {
+"group__API__MPI__Support.html#ga25408759187b030c633314855589ebcd":[5,27,91],
+"group__API__MPI__Support.html#ga2816a57287cd1a4babd27105936fc6ed":[5,27,109],
+"group__API__MPI__Support.html#ga2bfc2db9d324c76cae7a107ce3cd2cf8":[5,27,64],
 "group__API__MPI__Support.html#ga2c49e782fd50113aa0ce10a5168ab57f":[5,27,115],
 "group__API__MPI__Support.html#ga2c51b8748e6d5dde66ad0030f970e032":[5,27,114],
 "group__API__MPI__Support.html#ga35040bc190837c29086d83c73776bca5":[5,27,26],
@@ -246,8 +249,5 @@ var NAVTREEINDEX5 =
 "group__API__Modularized__Scheduler.html#structstarpu__sched__tree":[5,22,1],
 "group__API__OpenCL__Extensions.html":[5,15],
 "group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297":[5,15,0,0],
-"group__API__OpenCL__Extensions.html#ga002e85a0f6bcd087df54287de5ae5e07":[5,15,30],
-"group__API__OpenCL__Extensions.html#ga03f34ac98495afc5d0f268e366f80598":[5,15,15],
-"group__API__OpenCL__Extensions.html#ga06f19c27ac5147607acc511d49302321":[5,15,26],
-"group__API__OpenCL__Extensions.html#ga160dc78c0f6a90b5aa2200b49c5b4d7b":[5,15,1]
+"group__API__OpenCL__Extensions.html#ga002e85a0f6bcd087df54287de5ae5e07":[5,15,30]
 };
