@@ -1,5 +1,8 @@
 var NAVTREEINDEX6 =
 {
+"group__API__OpenCL__Extensions.html#ga03f34ac98495afc5d0f268e366f80598":[5,15,15],
+"group__API__OpenCL__Extensions.html#ga06f19c27ac5147607acc511d49302321":[5,15,26],
+"group__API__OpenCL__Extensions.html#ga160dc78c0f6a90b5aa2200b49c5b4d7b":[5,15,1],
 "group__API__OpenCL__Extensions.html#ga1b591248c13dc33e2e9b00ace593405e":[5,15,3],
 "group__API__OpenCL__Extensions.html#ga1d06b6c00b15f4fcd8d4c0c998f955ac":[5,15,21],
 "group__API__OpenCL__Extensions.html#ga23fa324d87f923f39f05bfdc9d3fe7e9":[5,15,6],
@@ -246,8 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Perf__Monitoring.html#ga15b96ecd4161e8abdea440ad89262766":[5,38,24],
 "group__API__Perf__Monitoring.html#ga1d3b734cccfcb02c47baa5412acf0877":[5,38,1],
 "group__API__Perf__Monitoring.html#ga247ff710854bfd7e3ab976b2ebad478e":[5,38,11],
-"group__API__Perf__Monitoring.html#ga2f9ddf6ae47cd7eba9b94499e37a301f":[5,38,13],
-"group__API__Perf__Monitoring.html#ga36c44ab10f14200d43704d8771246997":[5,38,8],
-"group__API__Perf__Monitoring.html#ga42a36dd17bcfd33dcca53e8cc28f56a7":[5,38,3],
-"group__API__Perf__Monitoring.html#ga466359135ffda3634e03a9c90809a71b":[5,38,26]
+"group__API__Perf__Monitoring.html#ga2f9ddf6ae47cd7eba9b94499e37a301f":[5,38,13]
 };
