@@ -1,5 +1,8 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Running__Drivers.html#ga497d48a24107dfebf6ef3ad40d4a6df8":[5,32,4],
+"group__API__Running__Drivers.html#ga68b320765b17e5e4a256f156c9932e69":[5,32,3],
+"group__API__Running__Drivers.html#gab274599ec82fe38cb41267b8a1384995":[5,32,5],
 "group__API__Running__Drivers.html#gac8f8848b64980676190d77d265fda841":[5,32,7],
 "group__API__Running__Drivers.html#gad6d01b57f2f84df90f554ea205dcf90d":[5,32,6],
 "group__API__Running__Drivers.html#structstarpu__driver":[5,32,0],
@@ -246,8 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Scheduling__Policy.html#ga9424eb90a56d08f804d85be6557ddf66":[5,24,45],
 "group__API__Scheduling__Policy.html#ga94edfd4a02666d8c1b8c506423586426":[5,24,19],
 "group__API__Scheduling__Policy.html#ga98ec28ae7ac484959f48b7a79372c1af":[5,24,31],
-"group__API__Scheduling__Policy.html#ga9e576ab0869a671c3cc482f385e1905b":[5,24,7],
-"group__API__Scheduling__Policy.html#gaa01a5b65a4c387da5f7ca711c03d41c8":[5,24,9],
-"group__API__Scheduling__Policy.html#gaa859b0ee59cfa2bde4d241f854c3bbea":[5,24,29],
-"group__API__Scheduling__Policy.html#gab291c2011e9679a07d2eb632d58ac90c":[5,24,38]
+"group__API__Scheduling__Policy.html#ga9e576ab0869a671c3cc482f385e1905b":[5,24,7]
 };
