@@ -1,5 +1,8 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Policy.html#gaa01a5b65a4c387da5f7ca711c03d41c8":[5,24,9],
+"group__API__Scheduling__Policy.html#gaa859b0ee59cfa2bde4d241f854c3bbea":[5,24,29],
+"group__API__Scheduling__Policy.html#gab291c2011e9679a07d2eb632d58ac90c":[5,24,38],
 "group__API__Scheduling__Policy.html#gab389801ed30db46c5620b3e0c0d6abd9":[5,24,4],
 "group__API__Scheduling__Policy.html#gab8e4a2cd9f4fbad7b20b1086494d842d":[5,24,13],
 "group__API__Scheduling__Policy.html#gac45e8699959436b91bcf9b0c56a805df":[5,24,1],
@@ -246,8 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#gab0ffe5622c5980444226f1ed8d6fee71":[5,18,27],
 "group__API__Workers.html#gab48ee9207771b65673f5bb18885c8a7c":[5,18,12],
 "group__API__Workers.html#gab568e2368c11f9fb362f04264ad4cd04":[5,18,65],
-"group__API__Workers.html#gabb530cc7597d5a135b900760f45c9cde":[5,18,61],
-"group__API__Workers.html#gac043c52077692456604a2f2f161b86ba":[5,18,57],
-"group__API__Workers.html#gac5ac7db6daab005d9c36c2481d984b66":[5,18,40],
-"group__API__Workers.html#gac6d06f4e22b63bf50bc8e836cf16f81f":[5,18,21]
+"group__API__Workers.html#gabb530cc7597d5a135b900760f45c9cde":[5,18,61]
 };
