@@ -1,5 +1,9 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Workers.html#gab568e2368c11f9fb362f04264ad4cd04":[7,18,65],
+"group__API__Workers.html#gabb530cc7597d5a135b900760f45c9cde":[7,18,61],
+"group__API__Workers.html#gac043c52077692456604a2f2f161b86ba":[7,18,57],
+"group__API__Workers.html#gac5ac7db6daab005d9c36c2481d984b66":[7,18,40],
 "group__API__Workers.html#gac6d06f4e22b63bf50bc8e836cf16f81f":[7,18,21],
 "group__API__Workers.html#gacb9d262c066c047ae55f691adc876db3":[7,18,16],
 "group__API__Workers.html#gacdc94f67f203028dbfc25a2e8b588bb5":[7,18,62],
@@ -154,100 +158,96 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[8,0,0,55],
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[9,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[8,0,0,56],
-"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[9,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[8,0,0,57],
-"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[9,0,0,58],
+"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[9,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[8,0,0,58],
+"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[9,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[8,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[9,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[8,0,0,60],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[9,0,0,60],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[8,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[9,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[8,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[9,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[9,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[8,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[8,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[9,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[8,0,0,65],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[9,0,0,65],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[8,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[9,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[8,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[9,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[8,0,0,68],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[9,0,0,68],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[8,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[9,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[9,0,0,70],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[8,0,0,70],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[9,0,0,71],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[8,0,0,71],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[9,0,0,72],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[8,0,0,72],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[9,0,0,73],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[8,0,0,73],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[9,0,0,74],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[8,0,0,74],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[9,0,0,75],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[8,0,0,75],
-"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[9,0,0,76],
-"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[8,0,0,76],
-"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[9,0,0,77],
-"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[8,0,0,77],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[9,0,0,78],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[8,0,0,78],
-"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[9,0,0,79],
-"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[8,0,0,79],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[8,0,0,80],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[9,0,0,80],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[8,0,0,81],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[9,0,0,81],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[9,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[8,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[9,0,0,83],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[8,0,0,83],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[9,0,0,84],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[8,0,0,84],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[9,0,0,85],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[8,0,0,85],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[9,0,0,86],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[8,0,0,86],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[9,0,0,87],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[8,0,0,87],
-"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[9,0,0,88],
-"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[8,0,0,88],
-"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[8,0,0,89],
-"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[9,0,0,89],
-"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[8,0,0,90],
-"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[9,0,0,90],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[8,0,0,91],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[9,0,0,91],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[8,0,0,92],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[9,0,0,92],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[8,0,0,93],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[9,0,0,93],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[8,0,0,94],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[9,0,0,94],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[8,0,0,95],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[9,0,0,95],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[8,0,0,96],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[9,0,0,96],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[8,0,0,97],
-"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[9,0,0,97],
-"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[8,0,0,98],
-"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[9,0,0,98],
-"interfacefstarpu__mod_1_1fstarpu__data__release.html":[8,0,0,99],
-"interfacefstarpu__mod_1_1fstarpu__data__release.html":[9,0,0,99],
-"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[8,0,0,100],
-"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[9,0,0,100],
-"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[8,0,0,101],
-"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html":[9,0,0,101],
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[8,0,0,102],
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html":[9,0,0,102],
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[8,0,0,103],
-"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods__with__args.html":[9,0,0,103],
-"interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[8,0,0,104],
-"interfacefstarpu__mod_1_1fstarpu__data__test__if__allocated__on__node.html":[9,0,0,104]
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[9,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[8,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[8,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[9,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[8,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[9,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[8,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[9,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[8,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[9,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[8,0,0,66],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[9,0,0,66],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[8,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[9,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[9,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[8,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[9,0,0,69],
+"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[8,0,0,69],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[9,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[8,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[9,0,0,71],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[8,0,0,71],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[9,0,0,72],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[8,0,0,72],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[9,0,0,73],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[8,0,0,73],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[9,0,0,74],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[8,0,0,74],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[9,0,0,75],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[8,0,0,75],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[9,0,0,76],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[8,0,0,76],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[9,0,0,77],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[8,0,0,77],
+"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[8,0,0,78],
+"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[9,0,0,78],
+"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[8,0,0,79],
+"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[9,0,0,79],
+"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[9,0,0,80],
+"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[8,0,0,80],
+"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[9,0,0,81],
+"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[8,0,0,81],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[9,0,0,82],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[8,0,0,82],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[8,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[9,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[9,0,0,84],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[8,0,0,84],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[9,0,0,85],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[8,0,0,85],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[9,0,0,86],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[8,0,0,86],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[8,0,0,87],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[9,0,0,87],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[8,0,0,88],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[9,0,0,88],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[8,0,0,89],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[9,0,0,89],
+"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[9,0,0,90],
+"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[8,0,0,90],
+"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[8,0,0,91],
+"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[9,0,0,91],
+"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[8,0,0,92],
+"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[9,0,0,92],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[9,0,0,93],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[8,0,0,93],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[9,0,0,94],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[8,0,0,94],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[8,0,0,95],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html":[9,0,0,95],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[9,0,0,96],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__readwrite__upgrade__submit.html":[8,0,0,96],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[9,0,0,97],
+"interfacefstarpu__mod_1_1fstarpu__data__partition__submit.html":[8,0,0,97],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[9,0,0,98],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node.html":[8,0,0,98],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[9,0,0,99],
+"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html":[8,0,0,99],
+"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[9,0,0,100],
+"interfacefstarpu__mod_1_1fstarpu__data__register__same.html":[8,0,0,100],
+"interfacefstarpu__mod_1_1fstarpu__data__release.html":[9,0,0,101],
+"interfacefstarpu__mod_1_1fstarpu__data__release.html":[8,0,0,101],
+"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[8,0,0,102],
+"interfacefstarpu__mod_1_1fstarpu__data__release__on__node.html":[9,0,0,102]
 };
