@@ -1,5 +1,9 @@
 var NAVTREEINDEX4 =
 {
+"group__API__HIP__Extensions.html#gad40f30899d319b57afe87e9f11e873e6":[7,16,11],
+"group__API__HIP__Extensions.html#gad433b07789156fd12e47cf35373d36c8":[7,16,3],
+"group__API__HIP__Extensions.html#gadc796fee8ebed3e8f4c12fb242f4c857":[7,16,4],
+"group__API__HIP__Extensions.html#gaea7ebef965850bb064607be8103e2c92":[7,16,9],
 "group__API__HeteroPrio.html":[7,25],
 "group__API__HeteroPrio.html#ga08616241ba1e2b52a418b7de4c03895a":[7,25,7],
 "group__API__HeteroPrio.html#ga1756abbc3f96c7e3330313d00f40ba05":[7,25,4],
@@ -245,9 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__MPI__Support.html#ga1998499da59f8849a7ee5de16b0f5bab":[7,27,48],
 "group__API__MPI__Support.html#ga1d0194c08bd343a68c833f449fb62fa8":[7,27,33],
 "group__API__MPI__Support.html#ga1def2741166f560a0fb91f012538087f":[7,27,117],
-"group__API__MPI__Support.html#ga223329eeb7c711b1b213604355981185":[7,27,7],
-"group__API__MPI__Support.html#ga234e28905c976ed1b03fcdf75812a06d":[7,27,23],
-"group__API__MPI__Support.html#ga23d04f0a7ca146314a02e4773dafde2e":[7,27,60],
-"group__API__MPI__Support.html#ga25408759187b030c633314855589ebcd":[7,27,91],
-"group__API__MPI__Support.html#ga2816a57287cd1a4babd27105936fc6ed":[7,27,109]
+"group__API__MPI__Support.html#ga223329eeb7c711b1b213604355981185":[7,27,7]
 };
