@@ -1,5 +1,9 @@
 var NAVTREEINDEX5 =
 {
+"group__API__MPI__Support.html#ga234e28905c976ed1b03fcdf75812a06d":[7,27,23],
+"group__API__MPI__Support.html#ga23d04f0a7ca146314a02e4773dafde2e":[7,27,60],
+"group__API__MPI__Support.html#ga25408759187b030c633314855589ebcd":[7,27,91],
+"group__API__MPI__Support.html#ga2816a57287cd1a4babd27105936fc6ed":[7,27,109],
 "group__API__MPI__Support.html#ga2bfc2db9d324c76cae7a107ce3cd2cf8":[7,27,64],
 "group__API__MPI__Support.html#ga2c49e782fd50113aa0ce10a5168ab57f":[7,27,115],
 "group__API__MPI__Support.html#ga2c51b8748e6d5dde66ad0030f970e032":[7,27,114],
@@ -245,9 +249,5 @@ var NAVTREEINDEX5 =
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component__prio__data":[7,22,3],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__component__specs":[7,22,7],
 "group__API__Modularized__Scheduler.html#structstarpu__sched__tree":[7,22,1],
-"group__API__OpenCL__Extensions.html":[7,15],
-"group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297":[7,15,0,0],
-"group__API__OpenCL__Extensions.html#ga002e85a0f6bcd087df54287de5ae5e07":[7,15,30],
-"group__API__OpenCL__Extensions.html#ga03f34ac98495afc5d0f268e366f80598":[7,15,15],
-"group__API__OpenCL__Extensions.html#ga06f19c27ac5147607acc511d49302321":[7,15,26]
+"group__API__OpenCL__Extensions.html":[7,15]
 };
