@@ -1,5 +1,9 @@
 var NAVTREEINDEX6 =
 {
+"group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297":[7,15,0,0],
+"group__API__OpenCL__Extensions.html#ga002e85a0f6bcd087df54287de5ae5e07":[7,15,30],
+"group__API__OpenCL__Extensions.html#ga03f34ac98495afc5d0f268e366f80598":[7,15,15],
+"group__API__OpenCL__Extensions.html#ga06f19c27ac5147607acc511d49302321":[7,15,26],
 "group__API__OpenCL__Extensions.html#ga160dc78c0f6a90b5aa2200b49c5b4d7b":[7,15,1],
 "group__API__OpenCL__Extensions.html#ga1b591248c13dc33e2e9b00ace593405e":[7,15,3],
 "group__API__OpenCL__Extensions.html#ga1d06b6c00b15f4fcd8d4c0c998f955ac":[7,15,21],
@@ -245,9 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Perf__Monitoring.html#ga0d09d776a8250c995d3e40d77bb10628":[7,38,33],
 "group__API__Perf__Monitoring.html#ga13f8e7f707f5bab7bc4f45291effd109":[7,38,15],
 "group__API__Perf__Monitoring.html#ga15b96ecd4161e8abdea440ad89262766":[7,38,24],
-"group__API__Perf__Monitoring.html#ga1d3b734cccfcb02c47baa5412acf0877":[7,38,1],
-"group__API__Perf__Monitoring.html#ga247ff710854bfd7e3ab976b2ebad478e":[7,38,11],
-"group__API__Perf__Monitoring.html#ga2f9ddf6ae47cd7eba9b94499e37a301f":[7,38,13],
-"group__API__Perf__Monitoring.html#ga36c44ab10f14200d43704d8771246997":[7,38,8],
-"group__API__Perf__Monitoring.html#ga42a36dd17bcfd33dcca53e8cc28f56a7":[7,38,3]
+"group__API__Perf__Monitoring.html#ga1d3b734cccfcb02c47baa5412acf0877":[7,38,1]
 };
