@@ -1,5 +1,9 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Perf__Monitoring.html#ga247ff710854bfd7e3ab976b2ebad478e":[7,38,11],
+"group__API__Perf__Monitoring.html#ga2f9ddf6ae47cd7eba9b94499e37a301f":[7,38,13],
+"group__API__Perf__Monitoring.html#ga36c44ab10f14200d43704d8771246997":[7,38,8],
+"group__API__Perf__Monitoring.html#ga42a36dd17bcfd33dcca53e8cc28f56a7":[7,38,3],
 "group__API__Perf__Monitoring.html#ga466359135ffda3634e03a9c90809a71b":[7,38,26],
 "group__API__Perf__Monitoring.html#ga4ef027a8fd9b4716e7ecd177457af6ae":[7,38,28],
 "group__API__Perf__Monitoring.html#ga569b970b6ccc9d4f2d6e12dc73aa6e1d":[7,38,23],
@@ -245,9 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling__Tool.html#unionstarpu__prof__tool__event__info":[7,41,1],
 "group__API__Random__Functions.html":[7,42],
 "group__API__Running__Drivers.html":[7,32],
-"group__API__Running__Drivers.html#a08415dd427f53b10ce4176ad77fade39":[7,32,0,1],
-"group__API__Running__Drivers.html#a50af396b52e8c54e4e3b23803105fc0e":[7,32,0,0],
-"group__API__Running__Drivers.html#ga119a52234aebe7fef5da42f9d3989402":[7,32,2],
-"group__API__Running__Drivers.html#ga497d48a24107dfebf6ef3ad40d4a6df8":[7,32,4],
-"group__API__Running__Drivers.html#ga68b320765b17e5e4a256f156c9932e69":[7,32,3]
+"group__API__Running__Drivers.html#a08415dd427f53b10ce4176ad77fade39":[7,32,0,1]
 };
