@@ -1,5 +1,9 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Policy.html#ga98ec28ae7ac484959f48b7a79372c1af":[7,24,31],
+"group__API__Scheduling__Policy.html#ga9e576ab0869a671c3cc482f385e1905b":[7,24,7],
+"group__API__Scheduling__Policy.html#gaa01a5b65a4c387da5f7ca711c03d41c8":[7,24,9],
+"group__API__Scheduling__Policy.html#gaa859b0ee59cfa2bde4d241f854c3bbea":[7,24,29],
 "group__API__Scheduling__Policy.html#gab291c2011e9679a07d2eb632d58ac90c":[7,24,38],
 "group__API__Scheduling__Policy.html#gab389801ed30db46c5620b3e0c0d6abd9":[7,24,4],
 "group__API__Scheduling__Policy.html#gab8e4a2cd9f4fbad7b20b1086494d842d":[7,24,13],
@@ -245,9 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#gaad05388dbafdd5397ebe080913a7b0c8":[7,18,19],
 "group__API__Workers.html#gaafe3ee2f7b074f95e8bc79eeabda0f0f":[7,18,4],
 "group__API__Workers.html#gab0ffe5622c5980444226f1ed8d6fee71":[7,18,27],
-"group__API__Workers.html#gab48ee9207771b65673f5bb18885c8a7c":[7,18,12],
-"group__API__Workers.html#gab568e2368c11f9fb362f04264ad4cd04":[7,18,65],
-"group__API__Workers.html#gabb530cc7597d5a135b900760f45c9cde":[7,18,61],
-"group__API__Workers.html#gac043c52077692456604a2f2f161b86ba":[7,18,57],
-"group__API__Workers.html#gac5ac7db6daab005d9c36c2481d984b66":[7,18,40]
+"group__API__Workers.html#gab48ee9207771b65673f5bb18885c8a7c":[7,18,12]
 };
