@@ -1,5 +1,8 @@
 var NAVTREEINDEX4 =
 {
+"group__API__Initialization__and__Termination.html#a53d18b801302e2ccae6af09c6cdbb2c5":[5,4,0,33],
+"group__API__Initialization__and__Termination.html#a58cc3a37dc4e60999c2c99b0ec0244ad":[5,4,0,1],
+"group__API__Initialization__and__Termination.html#a5a36072143f87103ee20ad3aff00a3b1":[5,4,0,44],
 "group__API__Initialization__and__Termination.html#a5eebc0c0effcab9b0f257debe96071ba":[5,4,0,11],
 "group__API__Initialization__and__Termination.html#a62170298d1991dc5a9deb44c641cd405":[5,4,0,21],
 "group__API__Initialization__and__Termination.html#a68e93f60a9f8e4c82ab2af6a9cd3888a":[5,4,0,6],
@@ -246,8 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__MPI__Support.html#ga63a3aa05bebafcc4b9cf67f73db6ecb6":[5,27,92],
 "group__API__MPI__Support.html#ga64b80afba4d16ef45a1baf4656a94c52":[5,27,81],
 "group__API__MPI__Support.html#ga67d1e5f67d39674590a2adc7c53ae185":[5,27,28],
-"group__API__MPI__Support.html#ga69699989814f54defa33b444e3e59c20":[5,27,116],
-"group__API__MPI__Support.html#ga6b5f6d7fdf83ed6a9e7d7016cb67ca70":[5,27,101],
-"group__API__MPI__Support.html#ga6ebb836a816647d2f00977ea749e53bc":[5,27,94],
-"group__API__MPI__Support.html#ga70687c70156fa88dcaf7be605566f42e":[5,27,57]
+"group__API__MPI__Support.html#ga69699989814f54defa33b444e3e59c20":[5,27,116]
 };
