@@ -1,5 +1,8 @@
 var NAVTREEINDEX8 =
 {
+"group__API__SC__Hypervisor.html#ga035e61bdee7a98948b3c7e2e0b55ef21":[5,47,38],
+"group__API__SC__Hypervisor.html#ga04164c5a91df51882e8bdd84fd1b1e3f":[5,47,10],
+"group__API__SC__Hypervisor.html#ga0829a2976a7bdba7b3b5ef2124b863b2":[5,47,21],
 "group__API__SC__Hypervisor.html#ga08b6cf1458859cdeebc6e53b5dd753cb":[5,47,45],
 "group__API__SC__Hypervisor.html#ga0a4b27500994ca2c56047a7da18c6216":[5,47,50],
 "group__API__SC__Hypervisor.html#ga3186197ffa198841262a976cb8544ec3":[5,47,28],
@@ -246,8 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Standard__Memory__Library.html#ga6ddda4b71de54cf079a84f7c4b683443":[5,44,29],
 "group__API__Standard__Memory__Library.html#ga71ec84f082fd96f53612e684eda0e178":[5,44,26],
 "group__API__Standard__Memory__Library.html#ga84894d9a6726bca707043f484bd1a8f5":[5,44,24],
-"group__API__Standard__Memory__Library.html#ga8601b3e35b74e9cbbcefd7a9b9c6d0b8":[5,44,3],
-"group__API__Standard__Memory__Library.html#ga864a3b576a56d686010cfd6c9d5ef14b":[5,44,28],
-"group__API__Standard__Memory__Library.html#ga889e8ea2a1becb4eff634e264973b261":[5,44,11],
-"group__API__Standard__Memory__Library.html#ga9b7c0ef6eadc190d1f0a1eeabc75e857":[5,44,6]
+"group__API__Standard__Memory__Library.html#ga8601b3e35b74e9cbbcefd7a9b9c6d0b8":[5,44,3]
 };
