@@ -1,5 +1,9 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Workers.html#ga5728fe0e4be069e45c4cd0ac0319d8a0":[7,18,47],
+"group__API__Workers.html#ga57687262112024abc0082b01b72ff0e8":[7,18,59],
+"group__API__Workers.html#ga5877310a0fae5f20967027fcb214c7aa":[7,18,37],
+"group__API__Workers.html#ga60b4a796a3dba40e5159158750805bf2":[7,18,25],
 "group__API__Workers.html#ga6312aa4b12ce7e06fe391bcafda6796a":[7,18,14],
 "group__API__Workers.html#ga65ceee59fa79646aa5d2447eb2b17037":[7,18,11],
 "group__API__Workers.html#ga6f3fbb6e918d0135ccb68473a8ee5ca1":[7,18,8],
@@ -176,78 +180,74 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[8,0,0,54],
 "interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[9,0,0,55],
 "interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[8,0,0,55],
-"interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[8,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[9,0,0,56],
-"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[8,0,0,57],
+"interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[8,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[9,0,0,57],
-"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[8,0,0,58],
+"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[8,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[9,0,0,58],
-"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[8,0,0,59],
+"interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[8,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[9,0,0,59],
-"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[9,0,0,60],
+"interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[8,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[8,0,0,60],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[9,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[8,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[8,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[9,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[8,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[9,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[8,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[9,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[8,0,0,65],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[9,0,0,65],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[9,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[8,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[9,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[8,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[9,0,0,68],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[8,0,0,68],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[8,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[9,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[8,0,0,70],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[9,0,0,70],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[8,0,0,71],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[9,0,0,71],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[9,0,0,72],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[8,0,0,72],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[9,0,0,73],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[8,0,0,73],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[9,0,0,74],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[8,0,0,74],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[8,0,0,75],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[9,0,0,75],
-"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[9,0,0,76],
-"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[8,0,0,76],
-"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[9,0,0,77],
-"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[8,0,0,77],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[9,0,0,78],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[8,0,0,78],
-"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[9,0,0,79],
-"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[8,0,0,79],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[8,0,0,80],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[9,0,0,80],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[8,0,0,81],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[9,0,0,81],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[8,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[9,0,0,82],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[9,0,0,83],
-"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[8,0,0,83],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[9,0,0,84],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[8,0,0,84],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[9,0,0,85],
-"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[8,0,0,85],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[9,0,0,86],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[8,0,0,86],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[9,0,0,87],
-"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[8,0,0,87],
-"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[9,0,0,88],
-"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[8,0,0,88],
-"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[9,0,0,89],
-"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html":[8,0,0,89],
-"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[8,0,0,90],
-"interfacefstarpu__mod_1_1fstarpu__data__partition.html":[9,0,0,90],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[8,0,0,91],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__clean.html":[9,0,0,91],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[8,0,0,92],
-"interfacefstarpu__mod_1_1fstarpu__data__partition__plan.html":[9,0,0,92]
+"interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[9,0,0,60],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[8,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[9,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[8,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[9,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[8,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[9,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[9,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[8,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[8,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[9,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[8,0,0,66],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[9,0,0,66],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[8,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[9,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[8,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[9,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[8,0,0,69],
+"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[9,0,0,69],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[9,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[8,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[9,0,0,71],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[8,0,0,71],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[9,0,0,72],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[8,0,0,72],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[9,0,0,73],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[8,0,0,73],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[9,0,0,74],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[8,0,0,74],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[8,0,0,75],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[9,0,0,75],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[9,0,0,76],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[8,0,0,76],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[9,0,0,77],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[8,0,0,77],
+"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[9,0,0,78],
+"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[8,0,0,78],
+"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[9,0,0,79],
+"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[8,0,0,79],
+"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[8,0,0,80],
+"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[9,0,0,80],
+"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[8,0,0,81],
+"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[9,0,0,81],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[8,0,0,82],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__alloc.html":[9,0,0,82],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[9,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__free.html":[8,0,0,83],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[9,0,0,84],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__array__set.html":[8,0,0,84],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[9,0,0,85],
+"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html":[8,0,0,85],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[9,0,0,86],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node.html":[8,0,0,86],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[9,0,0,87],
+"interfacefstarpu__mod_1_1fstarpu__data__idle__prefetch__on__node__prio.html":[8,0,0,87],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[9,0,0,88],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate.html":[8,0,0,88],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[9,0,0,89],
+"interfacefstarpu__mod_1_1fstarpu__data__invalidate__submit.html":[8,0,0,89],
+"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[9,0,0,90],
+"interfacefstarpu__mod_1_1fstarpu__data__is__on__node.html":[8,0,0,90]
 };
