@@ -1,5 +1,9 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c":[7,22,73],
+"group__API__Modularized__Scheduler.html#gad06fa143512ae761c452bf0adf685bae":[7,22,53],
+"group__API__Modularized__Scheduler.html#gad0e17cdc3def6bd7e9a9a17437969bdb":[7,22,19],
+"group__API__Modularized__Scheduler.html#gad76ac70069357b5a3d0ac0a1489016a2":[7,22,68],
 "group__API__Modularized__Scheduler.html#gae1aa931285a2b952473fc7def121c5cd":[7,22,16],
 "group__API__Modularized__Scheduler.html#gae1ac4bb35944de31705ba297aef1f9a1":[7,22,49],
 "group__API__Modularized__Scheduler.html#gae4532cd31d9d069b810bdf52db2e052e":[7,22,15],
@@ -245,9 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Parallel__Worker.html#ga88471707cf8021453892ca7d83124bea":[7,37,13],
 "group__API__Parallel__Worker.html#ga97cd9955370e77c3b251dfc5e94c2080":[7,37,17],
 "group__API__Parallel__Worker.html#ga9adce159e1660dcd3ef111816b75b04d":[7,37,28],
-"group__API__Parallel__Worker.html#ga9b42af113646bf23c74e890fd766af31":[7,37,25],
-"group__API__Parallel__Worker.html#gab630219c3f24cfa1b3c096bdd19d5868":[7,37,27],
-"group__API__Parallel__Worker.html#gac1c6a21a2748744b1de17f432112c275":[7,37,10],
-"group__API__Parallel__Worker.html#gac1d014c1fb54af6193472ecfccc65575":[7,37,36],
-"group__API__Parallel__Worker.html#gad448a91528b4cd29b0426b4cf753387b":[7,37,16]
+"group__API__Parallel__Worker.html#ga9b42af113646bf23c74e890fd766af31":[7,37,25]
 };
