@@ -1,5 +1,9 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Parallel__Worker.html#gab630219c3f24cfa1b3c096bdd19d5868":[7,37,27],
+"group__API__Parallel__Worker.html#gac1c6a21a2748744b1de17f432112c275":[7,37,10],
+"group__API__Parallel__Worker.html#gac1d014c1fb54af6193472ecfccc65575":[7,37,36],
+"group__API__Parallel__Worker.html#gad448a91528b4cd29b0426b4cf753387b":[7,37,16],
 "group__API__Parallel__Worker.html#gadc0266b4a673ad33bb6a39eaf22afc08":[7,37,9],
 "group__API__Parallel__Worker.html#gae3e9c312827d1aed06ba10928df08760":[7,37,15],
 "group__API__Parallel__Worker.html#gae6b207e422827171dc53b1ae2a842d46":[7,37,18],
@@ -245,9 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling.html#ga8a423df93ec48a7391b2f439357a5544":[7,40,9],
 "group__API__Profiling.html#ga8cbf499dd0d62647b874fcb48c281e6a":[7,40,15],
 "group__API__Profiling.html#ga8dc4665fdbbbf8ce8f1b905aa8411642":[7,40,10],
-"group__API__Profiling.html#ga8ded3aa2a94ec7a5cd46e2e70a918c65":[7,40,13],
-"group__API__Profiling.html#ga9373d4a06c86ebf9ae74b67233b8bad6":[7,40,23],
-"group__API__Profiling.html#gabbb944b14c4378e5c855d060c730169b":[7,40,17],
-"group__API__Profiling.html#gabd03420d04882a63dea2f39d225ae9d2":[7,40,14],
-"group__API__Profiling.html#gabeb22bbe8062a45507cfc6273aae51ae":[7,40,7]
+"group__API__Profiling.html#ga8ded3aa2a94ec7a5cd46e2e70a918c65":[7,40,13]
 };
