@@ -1,5 +1,9 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Profiling.html#ga9373d4a06c86ebf9ae74b67233b8bad6":[7,40,23],
+"group__API__Profiling.html#gabbb944b14c4378e5c855d060c730169b":[7,40,17],
+"group__API__Profiling.html#gabd03420d04882a63dea2f39d225ae9d2":[7,40,14],
+"group__API__Profiling.html#gabeb22bbe8062a45507cfc6273aae51ae":[7,40,7],
 "group__API__Profiling.html#gacf0b5499290848f07c97a32c6c2412db":[7,40,19],
 "group__API__Profiling.html#gad04bdc4bfc1e053441ba5c9f3db06a56":[7,40,4],
 "group__API__Profiling.html#gad126fc77826a0472b6bd872e7ceb40d4":[7,40,6],
@@ -245,9 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Scheduling__Policy.html#ga2c45db0c01e86497082c907b9cb0f4cc":[7,24,14],
 "group__API__Scheduling__Policy.html#ga2dc83adec9e479e967a1d1c2ae40f916":[7,24,30],
 "group__API__Scheduling__Policy.html#ga315482308105aa57ecc59e88f71823aa":[7,24,42],
-"group__API__Scheduling__Policy.html#ga318f5a51b8f948940c754df6962be263":[7,24,35],
-"group__API__Scheduling__Policy.html#ga3893905aa0eb62a541f268c6f37c491e":[7,24,44],
-"group__API__Scheduling__Policy.html#ga39d52be64d37a80809f256c749fd37ca":[7,24,32],
-"group__API__Scheduling__Policy.html#ga3aa31bfaf64f1281d2da89eac0dba84d":[7,24,5],
-"group__API__Scheduling__Policy.html#ga3b98f64aa4214721c743883605f23dc3":[7,24,43]
+"group__API__Scheduling__Policy.html#ga318f5a51b8f948940c754df6962be263":[7,24,35]
 };
