@@ -1,5 +1,9 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Policy.html#ga3893905aa0eb62a541f268c6f37c491e":[7,24,44],
+"group__API__Scheduling__Policy.html#ga39d52be64d37a80809f256c749fd37ca":[7,24,32],
+"group__API__Scheduling__Policy.html#ga3aa31bfaf64f1281d2da89eac0dba84d":[7,24,5],
+"group__API__Scheduling__Policy.html#ga3b98f64aa4214721c743883605f23dc3":[7,24,43],
 "group__API__Scheduling__Policy.html#ga3bf8df94c9ea3f1370b53fff54e72888":[7,24,21],
 "group__API__Scheduling__Policy.html#ga3dc8a0756db914507cd56782b3141dbb":[7,24,27],
 "group__API__Scheduling__Policy.html#ga3e9efb4ca2cbc1c74757e0a9cb0f26c6":[7,24,37],
@@ -245,9 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#ga45611e9799d1c32e826c5f2f6a642c65":[7,18,51],
 "group__API__Workers.html#ga479f8ed78324dca80ad746d0fee5d832":[7,18,7],
 "group__API__Workers.html#ga4998e4e1dfa0d121059c60f790496a03":[7,18,24],
-"group__API__Workers.html#ga53bac558c693f8cfdeef94bc6b64ab0b":[7,18,53],
-"group__API__Workers.html#ga5728fe0e4be069e45c4cd0ac0319d8a0":[7,18,47],
-"group__API__Workers.html#ga57687262112024abc0082b01b72ff0e8":[7,18,59],
-"group__API__Workers.html#ga5877310a0fae5f20967027fcb214c7aa":[7,18,37],
-"group__API__Workers.html#ga60b4a796a3dba40e5159158750805bf2":[7,18,25]
+"group__API__Workers.html#ga53bac558c693f8cfdeef94bc6b64ab0b":[7,18,53]
 };
