@@ -1,5 +1,8 @@
 var NAVTREEINDEX10 =
 {
+"group__API__Workers.html#ga0dd6ff2d77c6a520a6cc4c051eb40bfa":[6,18,18],
+"group__API__Workers.html#ga1056809a8cd464002ed4cad02cec33e4":[6,18,67],
+"group__API__Workers.html#ga130075042017ad3794ba2321743088c6":[6,18,50],
 "group__API__Workers.html#ga1552f16bc4b25d839efc732180efa130":[6,18,43],
 "group__API__Workers.html#ga173d616aefe98c33a47a847fd2fca37d":[6,18,9],
 "group__API__Workers.html#ga177bffe36c7df3f91aaebe2dd03b8cda":[6,18,2],
@@ -203,51 +206,48 @@ var NAVTREEINDEX10 =
 "interfacefstarpu__mod_1_1fstarpu__cublas__init.html":[7,0,0,54],
 "interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[8,0,0,55],
 "interfacefstarpu__mod_1_1fstarpu__cublas__shutdown.html":[7,0,0,55],
-"interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[8,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[7,0,0,56],
-"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[8,0,0,57],
+"interfacefstarpu__mod_1_1fstarpu__cuda__get__local__stream.html":[8,0,0,56],
 "interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[7,0,0,57],
+"interfacefstarpu__mod_1_1fstarpu__cuda__worker__get__count.html":[8,0,0,57],
 "interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[8,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__acquire.html":[7,0,0,58],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[8,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__advise__as__important.html":[7,0,0,59],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[8,0,0,60],
 "interfacefstarpu__mod_1_1fstarpu__data__assign__arbiter.html":[7,0,0,60],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[8,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[7,0,0,61],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[7,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[8,0,0,62],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[7,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[8,0,0,63],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[7,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[8,0,0,64],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[7,0,0,65],
-"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[8,0,0,65],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[7,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[8,0,0,66],
-"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[7,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[8,0,0,67],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[7,0,0,68],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[8,0,0,68],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[8,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[7,0,0,69],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[8,0,0,70],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[7,0,0,70],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[8,0,0,71],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[7,0,0,71],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[8,0,0,72],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[7,0,0,72],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[7,0,0,73],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[8,0,0,73],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[7,0,0,74],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[8,0,0,74],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[7,0,0,75],
-"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[8,0,0,75],
-"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[8,0,0,76],
-"interfacefstarpu__mod_1_1fstarpu__data__get__child.html":[7,0,0,76],
-"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[8,0,0,77],
-"interfacefstarpu__mod_1_1fstarpu__data__get__local__ptr.html":[7,0,0,77],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[8,0,0,78],
-"interfacefstarpu__mod_1_1fstarpu__data__get__nb__children.html":[7,0,0,78],
-"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html":[7,0,0,79]
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[8,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize.html":[7,0,0,61],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[8,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__deinitialize__submit.html":[7,0,0,62],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[8,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__alloc.html":[7,0,0,63],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[7,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__alloc.html":[8,0,0,64],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[7,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__free.html":[8,0,0,65],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[7,0,0,66],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__array__set.html":[8,0,0,66],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[7,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descr__set.html":[8,0,0,67],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[7,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__descrg__free.html":[8,0,0,68],
+"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[8,0,0,69],
+"interfacefstarpu__mod_1_1fstarpu__data__fetch__on__node.html":[7,0,0,69],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[8,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__allocate.html":[7,0,0,70],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[7,0,0,71],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__free.html":[8,0,0,71],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[7,0,0,72],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg.html":[8,0,0,72],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[7,0,0,73],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__arg__ptr.html":[8,0,0,73],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[8,0,0,74],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html":[7,0,0,74],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[8,0,0,75],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__child__ops__func.html":[7,0,0,75],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[8,0,0,76],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__get__nchildren__func.html":[7,0,0,76],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[7,0,0,77],
+"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html":[8,0,0,77]
 };
