@@ -1,5 +1,8 @@
 var NAVTREEINDEX4 =
 {
+"group__API__Explicit__Dependencies.html#gabaef95d742d03c96453905602e511050":[6,11,7],
+"group__API__Explicit__Dependencies.html#gabdb8d20fca507a93450fe775233dd20c":[6,11,15],
+"group__API__Explicit__Dependencies.html#gac350ef8b876d63fb8885377f789853d2":[6,11,0],
 "group__API__Explicit__Dependencies.html#gaccd7b337e14269be734af274fb11c1a4":[6,11,2],
 "group__API__Explicit__Dependencies.html#gada6692ca393aa820bc105252ca19830f":[6,11,1],
 "group__API__Explicit__Dependencies.html#gadbed48d64331463d4f9a9090933e5b9f":[6,11,14],
@@ -246,8 +249,5 @@ var NAVTREEINDEX4 =
 "group__API__Interop__Support.html#ga6f6adfe90ef0bb6f1a17750fb5424304":[6,50,36],
 "group__API__Interop__Support.html#ga775088fa987f23dcf1ff50484d04964a":[6,50,53],
 "group__API__Interop__Support.html#ga7821f8af5e91529e05e91ae0673c34b0":[6,50,11],
-"group__API__Interop__Support.html#ga8a6b1a42180b3e601e891d726dcf4997":[6,50,25],
-"group__API__Interop__Support.html#ga8e54df808c4f642b8fea3277dde90e2e":[6,50,45],
-"group__API__Interop__Support.html#ga9321c1faccaf4fb39480c91fdb82086e":[6,50,50],
-"group__API__Interop__Support.html#ga9334160aa826c82711b67b06f1344796":[6,50,58]
+"group__API__Interop__Support.html#ga8a6b1a42180b3e601e891d726dcf4997":[6,50,25]
 };
