@@ -1,5 +1,8 @@
 var NAVTREEINDEX6 =
 {
+"group__API__Modularized__Scheduler.html#ga70c74dee688684fb09e45833094ba21a":[6,22,26],
+"group__API__Modularized__Scheduler.html#ga72554d14205573f57631b850afa3f39f":[6,22,11],
+"group__API__Modularized__Scheduler.html#ga752889050651f6e3c83ddd2c3f96c0ff":[6,22,63],
 "group__API__Modularized__Scheduler.html#ga782b27a1b864b0d21294f3d8da8756f8":[6,22,60],
 "group__API__Modularized__Scheduler.html#ga79594b4403678fa1d6aa08f7fbe6e525":[6,22,44],
 "group__API__Modularized__Scheduler.html#ga795d692f797ef022c350c9b5922cec31":[6,22,40],
@@ -246,8 +249,5 @@ var NAVTREEINDEX6 =
 "group__API__Parallel__Tasks.html#gae3fe82c940e36715145baa9fe003e453":[6,19,7],
 "group__API__Parallel__Tasks.html#gae53499613fb72e9aa1abad6437a926f9":[6,19,2],
 "group__API__Parallel__Tasks.html#gaf99bc08bf6f586b658febdd1dc6fef80":[6,19,9],
-"group__API__Parallel__Worker.html":[6,37],
-"group__API__Parallel__Worker.html#ga01d8f8727b395aa7b49b77772b43f215":[6,37,1],
-"group__API__Parallel__Worker.html#ga0b55812dec189a94c1e54c06482336b9":[6,37,3],
-"group__API__Parallel__Worker.html#ga0b8011473a2abad180217861366c5a19":[6,37,20]
+"group__API__Parallel__Worker.html":[6,37]
 };
