@@ -1,5 +1,8 @@
 var NAVTREEINDEX7 =
 {
+"group__API__Parallel__Worker.html#ga01d8f8727b395aa7b49b77772b43f215":[6,37,1],
+"group__API__Parallel__Worker.html#ga0b55812dec189a94c1e54c06482336b9":[6,37,3],
+"group__API__Parallel__Worker.html#ga0b8011473a2abad180217861366c5a19":[6,37,20],
 "group__API__Parallel__Worker.html#ga186aa3508b97b85ec96a6bafe2b2d590":[6,37,32],
 "group__API__Parallel__Worker.html#ga1b7ba145bcc09b85fcd41c14611ed93c":[6,37,11],
 "group__API__Parallel__Worker.html#ga273e6531699a92373c8a1e64aa45703d":[6,37,2],
@@ -246,8 +249,5 @@ var NAVTREEINDEX7 =
 "group__API__Profiling.html#a6e85ac77428f572c5380e283b943459c":[6,40,0,16],
 "group__API__Profiling.html#a73a1303e033dffe94ff162e8e21122d1":[6,40,1,12],
 "group__API__Profiling.html#a78e32404bdff71292562d2dc5892061c":[6,40,0,15],
-"group__API__Profiling.html#a8032d6b4c3391555b255718d7da4279c":[6,40,2,0],
-"group__API__Profiling.html#a8786d0be02dcf901ae7cd8a295b30293":[6,40,1,3],
-"group__API__Profiling.html#a89ac253d44d475a9d2dfcb9153bd4b3a":[6,40,1,10],
-"group__API__Profiling.html#a8f1fe52f21a7fc58860cf2f163ec868a":[6,40,0,5]
+"group__API__Profiling.html#a8032d6b4c3391555b255718d7da4279c":[6,40,2,0]
 };
