@@ -1,5 +1,8 @@
 var NAVTREEINDEX8 =
 {
+"group__API__Profiling.html#a8786d0be02dcf901ae7cd8a295b30293":[6,40,1,3],
+"group__API__Profiling.html#a89ac253d44d475a9d2dfcb9153bd4b3a":[6,40,1,10],
+"group__API__Profiling.html#a8f1fe52f21a7fc58860cf2f163ec868a":[6,40,0,5],
 "group__API__Profiling.html#a8f4291afbbd7fcf885a3d30a72f2dd78":[6,40,0,10],
 "group__API__Profiling.html#a9e1ae88eb46e9b9867cb41d0584ace7b":[6,40,0,4],
 "group__API__Profiling.html#aa28c145b4543cceed05a1bba0478577e":[6,40,0,1],
@@ -246,8 +249,5 @@ var NAVTREEINDEX8 =
 "group__API__Scheduling__Contexts.html#gae6b235a9555a74e5cb4c89ca5117b419":[6,23,21],
 "group__API__Scheduling__Contexts.html#gae71c0da99dd6af6193dd85710caf6c13":[6,23,5],
 "group__API__Scheduling__Contexts.html#gaeb43bd3c56edb4bc4590eecc4eae76f0":[6,23,6],
-"group__API__Scheduling__Contexts.html#gaf213c18d752d78286cff68a379ee7611":[6,23,10],
-"group__API__Scheduling__Contexts.html#gaf9a95bcf18710622750367c0ba6acbb4":[6,23,34],
-"group__API__Scheduling__Contexts.html#gafe295aec3c152fe1fc0dd74e17f82961":[6,23,22],
-"group__API__Scheduling__Policy.html":[6,24]
+"group__API__Scheduling__Contexts.html#gaf213c18d752d78286cff68a379ee7611":[6,23,10]
 };
