@@ -1,5 +1,8 @@
 var NAVTREEINDEX9 =
 {
+"group__API__Scheduling__Contexts.html#gaf9a95bcf18710622750367c0ba6acbb4":[6,23,34],
+"group__API__Scheduling__Contexts.html#gafe295aec3c152fe1fc0dd74e17f82961":[6,23,22],
+"group__API__Scheduling__Policy.html":[6,24],
 "group__API__Scheduling__Policy.html#a0e378575c3d948a10e1025dd817bba67":[6,24,0,11],
 "group__API__Scheduling__Policy.html#a126aefb44f8c9927e8c46007c29aa92d":[6,24,0,3],
 "group__API__Scheduling__Policy.html#a1b1eade0d51badd5c9a2faaa49345b3e":[6,24,0,5],
@@ -246,8 +249,5 @@ var NAVTREEINDEX9 =
 "group__API__Workers.html#ae039a760cdd80c0d91bcc4c4da9ebb74":[6,18,1,5],
 "group__API__Workers.html#ae260b3aeb9f58a98d7adb70eea8b851c":[6,18,1,9],
 "group__API__Workers.html#ga03d66f459ebae08349fa50042fe37808":[6,18,46],
-"group__API__Workers.html#ga0c9b9b7f5195cb8cbc5ee1223ec0f264":[6,18,34],
-"group__API__Workers.html#ga0dd6ff2d77c6a520a6cc4c051eb40bfa":[6,18,18],
-"group__API__Workers.html#ga1056809a8cd464002ed4cad02cec33e4":[6,18,67],
-"group__API__Workers.html#ga130075042017ad3794ba2321743088c6":[6,18,50]
+"group__API__Workers.html#ga0c9b9b7f5195cb8cbc5ee1223ec0f264":[6,18,34]
 };
